@@ -31,6 +31,7 @@
 #include "skanpage_config.h"
 #include "skanpage_state.h"
 #include "skanpage_version.h"
+#include "NameTemplateUtils.h"
 
 int main(int argc, char *argv[])
 {
@@ -49,6 +50,7 @@ int main(int argc, char *argv[])
     qmlRegisterUncreatableType<Skanpage>("org.kde.skanpage", 1, 0, "Skanpage", QStringLiteral("Skanpage application class uncreateable"));
     qmlRegisterUncreatableType<SkanpageConfiguration>("org.kde.skanpage", 1, 0, "Configuration", QStringLiteral("Confguration class uncreatable"));
     qmlRegisterUncreatableType<SkanpageState>("org.kde.skanpage", 1, 0, "StateConfiguration", QStringLiteral("State class uncreatable"));
+    qmlRegisterUncreatableType<NameTemplateUtils>("org.kde.skanpage", 1, 0, "NameTemplate", QStringLiteral("NameTemplate class uncreatable"));
     qmlRegisterUncreatableMetaObject(SkanpageUtils::staticMetaObject, "org.kde.skanpage", 1, 0, "SkanpageUtils", QStringLiteral("Error: only enums"));
     qmlRegisterType<InProgressPainter>("org.kde.skanpage", 1, 0, "InProgressPainter");
     qRegisterMetaType<SkanpageUtils::MessageLevel>();
@@ -64,7 +66,7 @@ int main(int argc, char *argv[])
                          QLatin1String(SKANPAGE_VERSION_STRING),
                          i18n("Multi-page scanning application by KDE."),
                          KAboutLicense::GPL,
-                         i18n("© 2015-2022 Kåre Särs, Alexander Stippich"));
+                         i18n("© 2015–2022 Kåre Särs, Alexander Stippich"));
 
     aboutData.addAuthor(QStringLiteral("Kåre Särs"), i18n("developer"), QLatin1String("kare.sars@iki.fi"));
     aboutData.addAuthor(QStringLiteral("Alexander Stippich"), i18n("developer"), QLatin1String("a.stippich@gmx.net"));
@@ -78,7 +80,7 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     QCommandLineOption deviceOption(QStringList({QLatin1String("d"), QLatin1String("device")}),
-                                    i18n("Sane scanner device name. Use 'test' for test device."),
+                                    i18n("Sane scanner device name. Use “test” for test device."),
                                     i18n("device"));
     parser.addOption(deviceOption);
     QCommandLineOption dumpOption(QStringList({QLatin1String("o"), QLatin1String("options")}),
@@ -86,7 +88,7 @@ int main(int argc, char *argv[])
                                   QLatin1String("options.txt"));
     parser.addOption(dumpOption);
     QCommandLineOption importOption(QStringList({QLatin1String("i"), QLatin1String("import")}),
-                                    i18n("A local image or pdf file that shall be imported. Image formats must be supported by Qt."),
+                                    i18n("A local image or PDF file that shall be imported. Image formats must be supported by Qt."),
                                     QLatin1String("image"));
     parser.addOption(importOption);
     parser.process(app);
